/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Offroy.
Contributor(s): ______________________________________.

====================================================================*/
/*
 * Created on 23 mai 2003 by jerome OFFROY (offroy@lifl.fr)
 *
 */

package org.omg.lifl.eclipse.plugin.project.OpenCCM;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * @author LIFL
 *
 */
public class MainPlugin extends AbstractUIPlugin {

    private static MainPlugin fgPlugin;

    /**
     * @param descriptor
     */
    public MainPlugin(IPluginDescriptor descriptor) {
        super(descriptor);
        fgPlugin = this;
    }

    /**
     * Returns the shared instance.
     */
    public static MainPlugin getDefault() {
        return fgPlugin;
    }

    /**
     * Returns the workspace instance.
     */
    public static IWorkspace getWorkspace() {
        return ResourcesPlugin.getWorkspace();
    }

    /**
	 * @param name
	 * @return
	 */
	public ImageDescriptor getImageDescriptor(String name) {
        try {
            URL url = new URL(getDescriptor().getInstallURL(), name);
            return ImageDescriptor.createFromURL(url);
        } catch (MalformedURLException e) {
            return ImageDescriptor.getMissingImageDescriptor();
        }
    }

	public static String getPluginId() {
        return getDefault().getDescriptor().getUniqueIdentifier();
    }

    /**
	 * @param status
	 */
	public static void log(IStatus status) {
        getDefault().getLog().log(status);
    }

    /**
	 * @param message
	 */
	public static void log(String message) {
        log(
            new Status(
                IStatus.ERROR,
                getPluginId(),
                IStatus.ERROR,
                message,
                null));
    }

    /**
	 * @param e
	 */
	public static void log(Throwable e) {
        log(
            new Status(
                IStatus.ERROR,
                getPluginId(),
                IStatus.ERROR,
                "Internal Error",
                e));
    }

}
