/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Sylvain Leblanc.
Contributor(s): Christophe Demarey.

====================================================================*/

package DiningPhilosophers.cif;

/**
 * This is the CIDL-based implementation of
 * the OMG IDL3 DiningPhilosophers::PhilosopherHome home type.
 *
 * This class inherits from the generated home executor skeleton class
 * defined by OMG CIDL PhilosopherSessionComposition.PhilosopherSessionHome_impl.
 * 
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * @author <a href="mailto:Sylvain.Leblanc@lifl.fr">Sylvain Leblanc</a>
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 2.0
 */

public class PhilosopherHomeImpl
     extends DiningPhilosophers.PhilosopherSessionComposition.PhilosopherSessionHome_impl
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    PhilosopherHomeImpl()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for creation of component segments.
    //
    // ==================================================================

    /**
     * Create an executor segment from its identifier.
     *
     * @param segid The executor segment identifier.
     */
    public org.omg.Components.ExecutorSegmentBase
    create_executor_segment(int segid)
    {
        return new PhilosopherImpl();
    }

    // ==================================================================
    //
    // Methods for OMG IDL DiningPhilosophers::CCM_PhilosopherHome
    //
    // ==================================================================

    /**
     * Implementation of the 'new' factory operation.
     *
     * @param name The name of the philosopher to create.
     *
     * @return The EntrepriseComponent created executor.
     */
    public org.omg.Components.EnterpriseComponent
    _new(String name)
    {
        return new PhilosopherImpl(name);
    }

    // ==================================================================
    //
    // Methods for the deployment.
    //
    // ==================================================================

    /**
     * This method is called by the OpenCCM Component Server
     * to create a home instance.
     */
    public static org.omg.Components.HomeExecutorBase
    create_home()
    {
        return new PhilosopherHomeImpl();
    }

    // Executed once at the loading of this class
    // by the OpenCCM Component Server.
    static
    {
        // Required to register the StatusInfo valuetype factory to the ORB.
        DiningPhilosophers.StatusInfoFactoryHelper.register(new StatusInfoFactory());
    }
}
