/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frederic
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.ccm.Deployment;

// Package dependencies
import org.objectweb.util.cmdline.api.CommandLine;

import org.objectweb.util.cmdline.lib.ApplicationBase;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;
import org.objectweb.ccm.descriptor.componentassembly.*;
import org.objectweb.ccm.descriptor.componentassembly.beans.*;
import org.objectweb.ccm.descriptor.componentassembly.ccm.*;

/**
 * This is the Assembly object allowing to deploy
 * an application package.
 * TODO: Loading of intire xml tree representation since the instanctiation
 * of the assembly
 */
public class AssemblyImpl extends org.omg.Components.Deployment.AssemblyPOA {

    // xml handler path
    private String xmlFilePath;

    // Console for emittion of message
    private org.objectweb.util.cmdline.api.Console console;

    //Root  of xml tree cad representation
    private ComponentassemblyBean assemblyObject;

    //Table of component handle order by id key
    private java.util.Hashtable general;

    // State of the assembly
    private Assembly etat;

    public AssemblyImpl(String xmlFilePath){

    this.xmlFilePath=xmlFilePath;
    general=new java.util.Hashtable();
    etat=new AssemblyImplInactive();
    }



    /**
     * Inactive state for the assembly
     */
    private class AssemblyImplInactive implements Assembly
    {
    public void build() throws org.omg.Components.CreateFailure {
        try{

        //console.message("Load the tree");
        loadCADTree();

        /*SAve usefull information to deployment*/
        general.put("BaseDir",org.objectweb.ccm.deploytool.DeploymentProcess.getBaseDir());
        //general.put("__Console__",console);
        /*Start the deployment operation*/


        ((ComponentassemblyDeployer)
         assemblyObject
         .getExtensionManager().getExtensionByName("ccm.Deployer")
         .getInstance()).deployPartial(general,assemblyObject);

        ((ComponentassemblyDeployer)
         assemblyObject
         .getExtensionManager().getExtensionByName("ccm.Deployer")
         .getInstance()).deployFinal(general,assemblyObject);

        /*Setup the component to configuration complete state*/
        for (java.util.Enumeration enum = general.elements() ; enum.hasMoreElements() ; )
            {
                try {
                    ((org.omg.Components.CCMObject)
             enum.nextElement()).configuration_complete();
            }
            catch (java.lang.ClassCastException exception) {
            /*Nothing to do for non component objet like console*/
            }
            catch (org.omg.Components.InvalidConfiguration exception)
            {
                exception.printStackTrace();
                //console.error("Could not switch a CCM Object to configuration complete");
                return ;
            }
            }
        }
        catch(Exception e)
        {
            e.printStackTrace(); throw new org.omg.Components.CreateFailure();
        }
        etat=(Assembly) new AssemblyImplActive();
        registerAssembly() ;
    }


    /**
     * Private function allowing inactive assembly to load
     * tree representation of the xml cad file
     */
    private void loadCADTree()throws org.omg.Components.CreateFailure
    {
        // get the ORB
        org.omg.CORBA.ORB orb
        = org.objectweb.ccm.CORBA.TheORB.getORB();
        //console.message("Got the ORB");

        // inits OpenCCM runtime
        org.objectweb.ccm.Components.Runtime.init (orb);
        //console.message("OpenCCM runtime is ready");

        /*Creating the java file like with .CAD file*/
        java.io.File assemblyFile= new java.io.File (xmlFilePath);
        try {
        assemblyObject
            = (ComponentassemblyBean)
             org.objectweb.ccm.descriptor.componentassembly.beans.ComponentassemblyBeanImpl
            .unmarshalBean(assemblyFile);
        } catch (java.io.IOException ex)
        {
            ex.printStackTrace();
            console.error("Could not unmarshal the assembly file");
            throw new org.omg.Components.CreateFailure();
        }
        //console.message("Got the assembly descriptor");
    }

    /**
     * Break connection between composant and destroy them
     */
    public void tear_down() throws org.omg.Components.RemoveFailure
    {
        throw new  org.omg.Components.RemoveFailure();    
    }
    
    /**
     * Return the current assembly state    
     */
    public org.omg.Components.Deployment.AssemblyState get_state()
    {
        return     org.omg.Components.Deployment.AssemblyState.INACTIVE;

    }
    }

    /**
     * Internal class which represent an deploied assembly, only
     * tear_down() and get_state() operation are available
     */
    private class AssemblyImplActive implements Assembly{
    /**
     * Alway thrown CreateFailure exception because the assembly
     * is already deploied. This function is non available
     */
    public void build() throws org.omg.Components.CreateFailure
    {
        throw new org.omg.Components.CreateFailure();
    }

    /**
     *    Tear_down the assembly in 2 part:
     *        First tear_down connections
     *        Secondly erease instantiation
     *  Switch the internal state of the assembly to inactive state.
     */
    public void tear_down() throws org.omg.Components.RemoveFailure
    {
        try{
        ((ComponentassemblyDeployer)
         assemblyObject
         .getExtensionManager().getExtensionByName("ccm.Deployer")
         .getInstance()).tearDownConnections(general,(ComponentassemblyImpl)assemblyObject);
        ((ComponentassemblyDeployer)
         assemblyObject
         .getExtensionManager().getExtensionByName("ccm.Deployer")
         .getInstance()).tearDownInstantiations(general,(ComponentassemblyImpl)assemblyObject);

        etat=(Assembly)new AssemblyImplInactive();

        }
        catch(Exception e){e.printStackTrace();}

    }

    /**
     * Break connection between composant and destroy them
     */
    public org.omg.Components.Deployment.AssemblyState get_state()
    {
        return org.omg.Components.Deployment.AssemblyState.INSERVICE;
    }
    }

    /**
     *Internal function to register the assembly with the specified name in cad descriptor
     * in order to retrieve and tear_down the assembly later.
     */
    private void registerAssembly(){
    // retrieve the corba reference from the assembly object
    org.omg.CORBA.Object ref =
            this._this_object(org.objectweb.ccm.CORBA.TheORB.getORB());

    org.omg.Components.Deployment.Assembly assemblyRef =
        org.omg.Components.Deployment.AssemblyHelper.narrow(ref);

    // Obtain the Name Service.
    org.objectweb.ccm.CORBA.NamingContext ns =
        org.objectweb.ccm.CORBA.TheNameService.getNamingContext();

    // Bind the server object in the name service.
    ns.rebind(assemblyObject.getId(), assemblyRef);
    System.out.println("Assembly {"+assemblyObject.getId()+"} is referenced");
    }

    /*Delegation operation to the state assembly*/
    public void build() throws org.omg.Components.CreateFailure{
    etat.build();
    }

    public void tear_down() throws org.omg.Components.RemoveFailure {
    etat.tear_down();
    }


    public org.omg.Components.Deployment.AssemblyState get_state(){
    return etat.get_state();
    }

    /*public String getId(){return assemblyObject.getId();}*/


    /*public void setConsole(org.objectweb.util.cmdline.api.Console console){
      this.console=console;
      }*/
}
