/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey, Philippe Merle.
Contributor(s): .

====================================================================*/

package org.objectweb.corba.command.lib;

// Package dependencies.
// import org.objectweb.corba.command.api.IR3toIDL3;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;
import java.util.ArrayList;

/**
 * Implementation of the ir3_idl3 command.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.2
 */

public class IR3toIDL3
     extends GeneratorBase
  implements org.objectweb.corba.command.api.IR3toIDL3
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Import Option.*/
    private OptionMultipleArguments import_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    IR3toIDL3()
    {
        // Calls the GeneratorBase constructor.
        super(new DefaultCommandLine("ir3_idl3",
                                     "declaration",
                                     "Generate OMG IDL 3.0 for a declaration from the OpenCCM's Interface Repository",
                                     true),
              "generated.idl3");
 
        // Inits internal state.

        // Adds the import option.
        import_ = new OptionMultipleArguments(
                          "-i",
                          new String[] { "-i" },
                          "ir_object",
                          new String[] { "Add import ir_object statement" },
                          "",
                          true);
        getCommandLine().addOption(import_);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cmdline.api.Application
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Application
    //
    // ==================================================================

    /**
     * Runs the application.
     *
     * @param args The command line arguments.
     *
     * @return The status.
     */
    public int
    run(java.lang.String[] args)
    {
        // Inits the OpenCCM's Abstract Syntax Tree.
        if(!initAST())
            return -1;

        // Generates OMG IDL 3.0.
        if (!generate_idl3(args[0],
                           getOutputFileName(),
                           import_.getOptionArguments()))
            return -1;

        // All is OK.
        return 0;
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.CommandOnIR3
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.CommandOnAST
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Generator
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.corba.command.api.IR3toIDL3
    //
    // ==================================================================

    /**
     * Generates OMG IDL 3.0 for a scope.
     *
     * @param decl_name The scope to be generated.
     * @param outputfile The file name to write in.
     * @param imports IR declarations to import.
     *
     * @return True if ok, else false.
     */
    public boolean
    generate_idl3(String decl_name,
                  String outputfile,
                  String[] imports)
    {
        // Switch the OpenCCM Interface Repository in mode OMG IDL 3.0
        getComponentRepository().as_IDL3_repository();

        // Retrieves the scope to generate.
        org.objectweb.corba.ast.api.Scope scope = null;
        try
        {
            scope = (org.objectweb.corba.ast.api.Scope)getAST().lookup(decl_name);
        }
        catch(ClassCastException e)
        {
            getConsole().error(decl_name + "is not a scope!");
            return false;
        }

        if(scope == null)
        {
            getConsole().error("Declaration " + decl_name + " not found!");
            return false;
        }

        getConsole().message("Generating OMG IDL 3.0 for " + decl_name + "...");

        // Launchs the generator.
        org.objectweb.corba.generator.idl.api.IDL3Generator gen =
                         new org.objectweb.corba.generator.idl.lib.IDL3Generator(getAST());
        gen.initialize( outputfile,
                        new ArrayList(java.util.Arrays.asList(imports)),
                        "IR3toIDL3" );

        // Generates.
        try
        {
            gen.generate(scope);
        }
        catch(org.objectweb.corba.generator.common.lib.GenerationException ex)
        {
            report_exception(ex);
            return false;
        }

        getConsole().message("OMG IDL 3.0 generated in " + outputfile + ".");
        return true;
    }

    // ==================================================================
    //
    // Static public methods.
    //
    // ==================================================================

    /**
     * The main bootstrap method.
     *
     * @param args The command line arguments.
     */
    public static void
    main(String[] args)
    {
        IR3toIDL3 ir3_idl3 = new IR3toIDL3();
        ir3_idl3.runMain(args);
    }
}
