/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Mathieu Vadet, Christophe Demarey.
Contributor(s): _________________________________.

====================================================================*/

package org.objectweb.corba.generator.java.api;

/** To access all the AST Declaration. */
import org.objectweb.corba.ast.api.Declaration;

/** To use GenerationException. */
import org.objectweb.corba.generator.common.lib.GenerationException;



/**
 * Utility interface for Java mapping.
 *
 * @author <a href="mailto:Mathieu.Vadet@lifl.fr">Mathieu Vadet</a>
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.4
 */

public interface JavaTranslator
{
    /**
     * Translate a TypeRef into its java mapping.
     *
     * @param typeref - The TypeRef to translate.
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    toJava(org.objectweb.corba.ast.api.TypeRef typeref);

    /**
     * Translate a PsdlTypeRef into its java mapping.
     *
     * @param type - The PsdlTypeRef to translate.
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    toJava(org.objectweb.corba.ast.api.PsdlTypeRef type);

    /**
     * Translate a parameter into its java mapping.
     *
     * @param typeref - The TypeRef to translate.
     * @param mode - The parameter mode (in, out or inout).
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    toJava(org.objectweb.corba.ast.api.TypeRef type,
           int mode);

    /**
     * Translate a psdl parameter into its java mapping.
     *
     * @param type - The PsdlTypeRef to translate.
     * @param mode - The parameter mode (in, out or inout).
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    toJava(org.objectweb.corba.ast.api.PsdlTypeRef type,
           int mode);

    /**
     * Translate a psdl reference into its java mapping,
     * i.e. ref<A> => A.
     *
     * @param type - The PsdlTypeRef to translate.
     *
     * @return The resulting mapping.
     **/
    public java.lang.String
    RefToJava(org.objectweb.corba.ast.api.PsdlTypeRef type);
    
    /**
     * Check if id is a java keyword.
     *
     * @param id - The string to check
     *
     * @return A valid string.
     **/
    public java.lang.String
    checkKeywords(java.lang.String id);

    /**
     * Get the java absolute name of a declaration
     * ( i.e. package.decl_name ).
     *
     * @param decl - The declaration to translate
     *
     * @return The java absolute name.
     **/
    public java.lang.String
    getAbsoluteName(Declaration decl);

    /**
     * Get the package of a declaration.
     *
     * @param decl - The declaration to translate
     *
     * @return The java package name.
     **/
    public java.lang.String
    getPackage(Declaration decl);

    /**
     * Get the java path of a declaration.
     * This don't include the declaration's java name.
     * The package name is translated to a path.
     *
     * @param decl - The declaration to translate
     *
     * @return The java package name.
     **/
    public String
    getAsDirectory(String package_name);

    /**
     * Get the java path of a declaration.
     * This don't include the declaration's java name.
     * The package name is translated to a path.
     *
     * @param decl - The declaration to translate
     *
     * @return The java package name.
     **/
    public java.lang.String
    getAsDirectory(Declaration decl);

    /**
     * Create directories for a given path,
     * including any necessary but nonexistent parent directories.
     *
     * @param dir - A directory.
     **/
    public void
    mkdir(java.io.File dir)
    throws GenerationException;

    /**
     * Create directories for a given path,
     * including any necessary but nonexistent parent directories.
     *
     * @param dir_name - A pathname string.
     *
     * @return The corresponding File.
     **/
    public java.io.File
    mkdir(String dir_name)
    throws GenerationException;
}
