/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.corba.generator.psdl.lib;

import org.objectweb.corba.ast.api.TypeKind;
import org.objectweb.corba.ast.api.DeclarationKind;


/**
 * This class implements useful methods dor PSDL types.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 */

public class PSDLTools
{

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     */

    public PSDLTools()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    /**
     * Test if a psdl type is an abstract storage type.
     *
     * @param type - The psdl type reference to test.
     *
     * @return True if this type is an abstract storage type, else false.
     **/
    public static boolean
    isAbstractStorageType(org.objectweb.corba.ast.api.PsdlTypeRef type)
    {
        org.objectweb.corba.ast.api.StorageTypeBase st_base = null;

        st_base = type.getStorageTypeBase();
        if ( (st_base != null)
             && (st_base.getDeclKind() == DeclarationKind.dk_abstract_storage_type) )
        {
            return true;
        }
        return false;
    }

    /**
     * Test if a psdl type is immutable.
     *
     * @param type - The psdl type reference to test.
     *
     * @return True if this type is immutable, else false.
     **/
    public static boolean
    isImmutable(org.objectweb.corba.ast.api.PsdlTypeRef type)
    {
        org.objectweb.corba.ast.api.TypeRef idl_type = null;

        idl_type = type.getTypeRef();
        if (idl_type != null)
        {
            TypeKind tk = idl_type.getTypeKind();

            if ( (tk == TypeKind.tk_null)
                 || (tk == TypeKind.tk_void)
                 || (tk ==  TypeKind.tk_short)
                 || (tk == TypeKind.tk_ushort)
                 || (tk == TypeKind.tk_long)
                 || (tk == TypeKind.tk_ulong)
                 || (tk == TypeKind.tk_longlong)
                 || (tk == TypeKind.tk_ulonglong)
                 || (tk == TypeKind.tk_float)
                 || (tk == TypeKind.tk_double)
                 || (tk == TypeKind.tk_longdouble)
                 || (tk == TypeKind.tk_boolean)
                 || (tk == TypeKind.tk_char)
                 || (tk == TypeKind.tk_wchar)
                 || (tk == TypeKind.tk_octet)
                 || (tk == TypeKind.tk_string)
                 || (tk == TypeKind.tk_wstring)
                 || (tk == TypeKind.tk_fixed) )
            {
                return true;
            }
        }
        return false;
    }

    /**
     * Test if a psdl type is a reference to an Abstract Storage Type.
     *
     * @param type - The psdl type reference to test.
     *
     * @return True if a reference to an Abstract Storage Type is immutable, else false.
     **/
    public static boolean
    isAbstractStorageTypeReference(org.objectweb.corba.ast.api.PsdlTypeRef type)
    {
        org.objectweb.corba.ast.api.StorageTypeBase st_base = null;

        st_base = type.getStorageTypeBase();
        if ( type.isRef() &&
             (st_base.getDeclKind() == DeclarationKind.dk_abstract_storage_type)
            )
            return true;
        return false;
    }
}
