/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.CORBA;

/** The administration console's API imports */
import org.objectweb.util.browser.naming.api.Context;
import org.objectweb.util.browser.naming.wrappers.common.AbstractContext;
import org.objectweb.util.browser.naming.api.Name;
import org.objectweb.util.browser.naming.api.Entry;
import org.objectweb.util.browser.naming.api.EntryIterator;
import org.objectweb.util.browser.naming.wrappers.common.DefaultName;
import org.objectweb.util.browser.naming.wrappers.common.DefaultEntry;
import org.objectweb.util.browser.naming.wrappers.common.DefaultIterator;

/** To use the Container class. */
import org.omg.CORBA.Container;
import org.omg.CORBA.Contained;

/**
 * Basic implementation of the Context interface
 * for managing Container object.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */

public class ContainerContext extends AbstractContext {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The container. */
    private Container container_ = null;

    // ==================================================================
    //
    // No Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    /**
     * Returns a new {@link EntryIterator EntryIterator} to
     * iterate on the entries contained by the target context.
     *
     * @return A new EntryIterator.
     */
    public EntryIterator getOWEntries() {
        Contained[] objects = container_.contents(org.omg.CORBA.DefinitionKind.dk_all, true);
        Entry[] values = new Entry[objects.length];
        for (int i = 0; i < objects.length; i++)
            values[i] = new DefaultEntry(objects[i], new DefaultName(objects[i].name()), this);
        return new DefaultIterator(values);
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     *
     * @param object The object to wrap
     *
     */
    public void setWrapped(Object object) {
        container_ = (Container) object;
    }

    /**
     * Gets the wrapped object
     *
     * @return The wrapped object
     *
     */
    public Object getWrapped() {
        return container_;
    }

    /**
     * Gets the hashCode of the wrapped object
     *
     * @return The hashCode of the wrapped object
     * 
     */
    public int getWrappedHashCode() {
        if (container_ != null)
            return container_.hashCode();
        else
            return 0;
    }

}
