/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.CORBA;

/** The administration console's API imports */
import org.objectweb.util.browser.naming.api.Context;
import org.objectweb.util.browser.naming.wrappers.common.AbstractContext;
import org.objectweb.util.browser.naming.wrappers.common.DefaultIterator;
import org.objectweb.util.browser.naming.api.Name;
import org.objectweb.util.browser.naming.api.Entry;
import org.objectweb.util.browser.naming.api.EntryIterator;

/** To use the POA interface */
import org.omg.PortableServer.POA;

/**
 * Basic implementation of the Context interface
 * for managing POA
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class POAContext extends AbstractContext {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The POA. */
    private POA poa_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Obtains the associated naming context.
     *
     * @return The associated naming context.
     */
    protected POA getPOA() {
        return poa_;
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    /**
     * Gets a local entry in the target context identified by <code>name</code>,
     * or null if no entry exists under name <code>name</code>.
     *
     * Here is a local resolution in the target context.
     *
     * This method does not modify the target context.
     *
     * @param name The name of the entry to be retrieved.
     *
     * @return The corresponding entry, if any; or null otherwise.
     *
     * @postcondition
     *      result.getOWName().getOWId().equals(name)
     *  and result.getOWContext() == this
     *  and this.isNotModified();
     */
    public Entry getOWLocalEntry(String name) {
        if (getPOA() != null) {
            // ???
            Object value = getOWLocalValue(name);

            // Returns a created entry if name is found, otherwise null.
            return (value != null) ? createEntry(value, name) : null;
        }
        return null;
    }

    /**
     * Gets the value of a local entry in the target context identified by
     * <code>name</code>, or null if no entry exists under name
     * <code>name</code>.
     *
     * This method is equivalent to
     * {@link #getOWLocalEntry(String) <code>getOWLocalEntry(name)</code>}
     * {@link Entry#getOWValue() <code>.getOWValue()</code>}.
     *
     * This method does not modify the target context.
     *
     * @param name The name of the entry to be retrieved. 
     * The form of the informations are "id:kind"
     *
     * @return The corresponding entry value, if any; or null otherwise.
     *
     * @postcondition
     *     ( getOWLocalEntry(name) == null && result == null )
     *  or result == getOWLocalEntry(name).getOWValue());
     */
    public Object getOWLocalValue(String name) {
        if (getPOA() != null) {
            POA obj = null;
            try {
                obj = poa_.find_POA(name, false);
            } catch (org.omg.PortableServer.POAPackage.AdapterNonExistent e) {
                System.out.println("AdapterNonExistent");
            }
            return obj;
        }
        return null;
    }

    /**
     * Returns a new {@link EntryIterator EntryIterator} to
     * iterate on the entries contained by the target context.
     *
     * @return A new EntryIterator.
     */
    public EntryIterator getOWEntries() {
        POA[] objects = getPOA().the_children();
        Entry[] values = new Entry[objects.length];
        for (int i = 0; i < values.length; i++)
            values[i] = getOWLocalEntry(objects[i].the_name());
        return new DefaultIterator(values);
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     *
     * @param object The object to wrap
     *
     */
    public void setWrapped(Object object) {
        poa_ = (POA) object;
    }

    /**
     * Gets the wrapped object
     *
     * @return The wrapped object
     *
     */
    public Object getWrapped() {
        return poa_;
    }

    /**
     * Gets the hashCode of the wrapped object
     *
     * @return The hashCode of the wrapped object
     *
     */
    public int getWrappedHashCode() {
        if (poa_ != null)
            return poa_.hashCode();
        else
            return 0;
    }

}
