/*===========================================================================

ObjectWeb Browser Framework
Copyright (C) 2003 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jrme Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.Components;

/** The consoles's imports */
import org.objectweb.util.browser.naming.wrappers.common.AbstractContext;
import org.objectweb.openccm.browser.CORBA.TypageCORBA;
import org.objectweb.util.browser.naming.api.Entry;
import org.objectweb.util.browser.naming.api.EntryIterator;
import org.objectweb.util.browser.naming.wrappers.common.DefaultEntry;
import org.objectweb.util.browser.naming.wrappers.common.DefaultName;
import org.objectweb.util.browser.naming.wrappers.common.DefaultIterator;
import org.omg.Components.ReceptacleDescription;
import org.omg.Components.ConnectionDescription;

/**
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class ReceptacleContext extends AbstractContext {

    /** The ReceptacleContainer which contains the ReceptacleDescription to browse */
    protected ReceptacleContainer receptacle_ = null;

    protected String getName(org.omg.CORBA.Object o) {
        TypageCORBA tc = new TypageCORBA(o, org.objectweb.ccm.CORBA.TheORB.getORB());
        return tc.getTypeID();
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    /**
     * Returns a new EntryIterator to
     * iterate on the entries contained by the target context.
     *
     * @return A new EntryIterator.
     */
    public EntryIterator getOWEntries() {
        ReceptacleDescription r = (ReceptacleDescription) receptacle_.getReceptacle();
        ConnectionDescription[] cd = r.connections;
        Entry[] values = new Entry[cd.length];
        for (int i = 0; i < cd.length; i++) {
            ConnectionContainer cc = new ConnectionContainer();
            cc.setConnection(cd[i]);
            cc.setReceptacleContainer(receptacle_);
            values[i] = new DefaultEntry(cc, new DefaultName(getName(cd[i].objref) + " (" + i + ")"), this);
        }
        return new DefaultIterator(values);
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     * @param object The object to wrap
     */
    public void setWrapped(Object object) {
        receptacle_ = (ReceptacleContainer) object;
    }

    /**
     * Gets the wrapped object
     * @return The wrapped object
     */
    public Object getWrapped() {
        return receptacle_;
    }

    /**
     * Gets the hashCode of the wrapped object
     * @return The hashCode of the wrapped object 
     */
    public int getWrappedHashCode() {
        if (receptacle_ != null)
            return receptacle_.hashCode();
        else
            return 0;
    }

}
