/*===========================================================================
ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.CosNaming;

/** The administration console's API imports */
import org.objectweb.util.browser.api.ExtendedActionListener;
import org.objectweb.util.browser.api.ExtendedActionEvent;
import org.objectweb.util.browser.gui.common.TreeView;
import org.objectweb.openccm.browser.menu.BrowserPanel;
import org.objectweb.openccm.browser.menu.OpenCCMBrowserConstants;

/** The java API's imports */
import javax.swing.JOptionPane;
import java.awt.Component;
import java.io.File;
import java.io.BufferedReader;
import java.io.FileReader;

/** The CORBA's imports */
import org.omg.CORBA.ORB;
import org.omg.CosNaming.NamingContext;

/**
 * This action binds an object into the NameService
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class BindObject implements ExtendedActionListener {

    /**
     * Binds the object into the current NameService
     */
    protected void bind(NamingContext naming, String id, org.omg.CORBA.Object o) {
        org.omg.CosNaming.NameComponent[] name = new org.omg.CosNaming.NameComponent[1];
        name[0] = new org.omg.CosNaming.NameComponent();
        name[0].id = id;
        name[0].kind = "";
        try {
            naming.rebind(name, o);
        } catch (org.omg.CosNaming.NamingContextPackage.NotFound err) {
            System.out.println("Object not found ! ");
        } catch (org.omg.CosNaming.NamingContextPackage.CannotProceed err) {
            System.out.println("CannotProceed exception !");
        } catch (org.omg.CosNaming.NamingContextPackage.InvalidName err) {
            System.out.println("InvalidName exception !");
        }
    }

    public void actionPerformed(ExtendedActionEvent e) {

        NamingContext naming = (NamingContext) e.getCurrentValue();
        BrowserPanel bp = new BrowserPanel("Object's name : ", "IOR file : ", OpenCCMBrowserConstants.IOR_FILE_CHOOSER);

        int result =
            JOptionPane.showOptionDialog(
                (Component) e.getActionEvent().getSource(),
                bp,
                "Binds an object into the NameService",
                JOptionPane.OK_CANCEL_OPTION,
                JOptionPane.PLAIN_MESSAGE,
                null,
                null,
                null);
        if (result == 0) {
            File file = bp.getFile();
            Object selectedObject = bp.getSelectedObject();
            org.omg.CORBA.Object object = null;
            if (file != null) {
                String ior = null;
                try {
                    BufferedReader in = new BufferedReader(new FileReader(file));
                    ior = in.readLine();
                } catch (java.io.FileNotFoundException err) {
                    System.out.println(file + " : File not found !");
                } catch (java.io.IOException err) {
                    System.out.println(file + " : Error while reading !");
                }
                if (ior != null && ior.startsWith("IOR:")) {
                    ORB orb = org.objectweb.ccm.CORBA.TheORB.getORB();
                    object = orb.string_to_object(ior);
                }
            } else if (selectedObject != null) {
                try {
                    object = (org.omg.CORBA.Object) selectedObject;
                } catch (ClassCastException e1) {
                    JOptionPane.showMessageDialog(null, "You must select a org.omg.CORBA.Object \n Found : " + selectedObject.getClass().getName(), "Bad Object !", JOptionPane.ERROR_MESSAGE);
                }
            }
            if (object != null && bp.getLabel() != null && bp.getLabel().length() > 0)
                bind(naming, bp.getLabel(), object);
            else
                JOptionPane.showMessageDialog(null, "One parameter is missing !", "Error !", JOptionPane.ERROR_MESSAGE);
        }
    }

}
