/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.CosNaming;

/** The administration console's API imports */
import org.objectweb.util.browser.naming.api.EntryIterator;
import org.objectweb.util.browser.naming.api.Entry;

/**
 * Basic implementation of the EntryIterator interface
 * on top of naming service.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */

public class NameServiceIterator implements EntryIterator {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The associated context. */
    protected NameServiceContext ctx_;

    /** The list of objects referenced in this naming context. */
    protected org.omg.CosNaming.BindingIteratorHolder bindingIterator_;

    /** To know if a binding doesn't be return because of a hasNext() invokation */
    protected boolean has_next_;
    protected boolean result_is_known_;
    protected org.omg.CosNaming.BindingHolder binding_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Constructs a DefaultEntryIterator from a Naming context instance.
     *
     * @param ctx The NamingContext.
     */
    public NameServiceIterator(NameServiceContext ctx) {
        // Inits internal state.
        ctx_ = ctx;
        org.omg.CosNaming.BindingListHolder bindingList_ = new org.omg.CosNaming.BindingListHolder();
        bindingIterator_ = new org.omg.CosNaming.BindingIteratorHolder();
        org.omg.CosNaming.NamingContext naming = ctx.getNamingContext();
        naming.list(0, bindingList_, bindingIterator_);
        result_is_known_ = false;
        binding_ = new org.omg.CosNaming.BindingHolder();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Saves the result of the next_one() invokation. 
     * Indeed, it takes the next binding and he says if there is more elements in the same method.
     */
    protected void getNextElement() {
        if (!result_is_known_) {
            if (bindingIterator_.value != null) {
                has_next_ = bindingIterator_.value.next_one(binding_);
                result_is_known_ = true;
            }
        }
    }

    // ==================================================================
    //
    // Public methods for interface EntryIterator.
    //
    // ==================================================================

    /**
     * Returns true if the iteration has more entries.
     *
     * In other words, returns true if next would return an entry
     * rather than throwing an exception.
     *
     * @return true if the iterator has more entries.
     */
    public boolean hasNext() {
        getNextElement();
        return has_next_;
    }

    /**
     * Returns the next entry in the interation.
     *
     * @return The next entry in the iteration.
     *
     * @exception NoSuchElementException Iteration has no more entries.
     */
    public Entry next() {
        getNextElement();
        result_is_known_ = false;
        org.omg.CosNaming.NameComponent[] nameComponents_ = binding_.value.binding_name;
        Entry result = ctx_.getOWLocalEntry(nameComponents_[0].id + ":" + nameComponents_[0].kind);
        return result;
    }

    /**
     * Removes from the underlying collection the last entry returned by
     * the iterator (optional operation). This method can be called only
     * once per call to next. The behavior of an iterator is unspecified
     * if the underlying collection is modified while the iteration is
     * in progress in any way other than by calling this method.
     *
     * @exception UnsupportedOperationException
     *            If the remove operation is not supported by
     *            this EntryIterator.
     *
     * @exception IllegalStateException
     *            If the next method has not yet been called,
     *            or the remove method has already been called
     *            after the last call to the next method.
     */
    public void remove() {
        // TODO: Must be implemented!!!!
        throw new UnsupportedOperationException();
    }
}
