/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.Deployment;

/** The console's imports. */
import org.objectweb.util.browser.naming.api.Context;
import org.objectweb.util.browser.naming.wrappers.common.AbstractContext;
import org.objectweb.util.browser.naming.wrappers.common.DefaultIterator;
import org.objectweb.util.browser.naming.api.Name;
import org.objectweb.util.browser.naming.api.Entry;
import org.objectweb.util.browser.naming.api.EntryIterator;

/** The CCM's imports */
import org.objectweb.ccm.Deployment.Server;

/**
 * Basic implementation of the Context interface
 * for managing Server object.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */

public class DeploymentServerContext extends AbstractContext {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The orb. */
    private Server server_ = null;

    // ==================================================================
    //
    // No Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Obtains the associated ORB.
     *
     * @return The associated ORB.
     */
    protected Server getServer() {
        return server_;
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    /**
     * Gets a local entry in the target context identified by <code>name</code>,
     * or null if no entry exists under name <code>name</code>.
     *
     * Here is a local resolution in the target context.
     *
     * This method does not modify the target context.
     *
     * @param name The name of the entry to be retrieved.
     *
     * @return The corresponding entry, if any; or null otherwise.
     *
     * @postcondition
     *      result.getOWName().getOWId().equals(name)
     *  and result.getOWContext() == this
     *  and this.isNotModified();
     */
    public Entry getOWLocalEntry(String name) {
        if (getServer() != null) {
            // ???
            Object value = getOWLocalValue(name);

            // Returns a created entry if name is found, otherwise null.
            return (value != null) ? createEntry(value, name) : null;
        }
        return null;
    }

    /**
     * Gets the value of a local entry in the target context identified by
     * <code>name</code>, or null if no entry exists under name
     * <code>name</code>.
     *
     * This method is equivalent to
     * {@link #getOWLocalEntry(String) <code>getOWLocalEntry(name)</code>}
     * {@link Entry#getOWValue() <code>.getOWValue()</code>}.
     *
     * This method does not modify the target context.
     *
     * name value :
     *   - ComponentServer to obtain the ComponentServer object
     *   - ComponentInstallation to obtain the ComponentInstallation object
     *
     *
     * @param name The name of the entry to be retrieved.
     *
     * @return The corresponding entry value, if any; or null otherwise.
     *
     * @postcondition
     *     ( getOWLocalEntry(name) == null && result == null )
     *  or result == getOWLocalEntry(name).getOWValue());
     */
    public Object getOWLocalValue(String name) {
        if (getServer() != null) {
            if (name.equals("ComponentServer"))
                return server_.provide_component_server();
            else if (name.equals("ComponentInstallation"))
                return server_.provide_install();
        }
        return null;
    }

    /**
     * Returns a new {@link EntryIterator EntryIterator} to
     * iterate on the entries contained by the target context.
     *
     * @return A new EntryIterator.
     */
    public EntryIterator getOWEntries() {
        String[] objects = new String[] { "ComponentServer", "ComponentInstallation" };
        Entry[] values = new Entry[objects.length];
        for (int i = 0; i < objects.length; i++)
            values[i] = getOWLocalEntry(objects[i]);
        return new DefaultIterator(values);
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     *
     * @param object The object to wrap
     *
     */
    public void setWrapped(Object object) {
        server_ = (Server) object;
    }

    /**
     * Gets the wrapped object
     *
     * @return The wrapped object
     *
     */
    public Object getWrapped() {
        return server_;
    }

    /*
     * Gets the hashCode of the wrapped object
     *
     * @return The hashCode of the wrapped object
     * 
     */
    public int getWrappedHashCode() {
        if (server_ != null)
            return server_.hashCode();
        else
            return 0;
    }

}
