/*====================================================================

ObjectWeb Util Package.
Copyright (C) 2003 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.api;

/**
 * This class encapsulates any Java Exception object allowing us
 * to avoid to throw them in every operation signatures.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public class ExceptionWrapper
     extends java.lang.Error
   implements ExceptionHolder
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** To store the wrapped Java Exception object. */
    private Exception exception_ = null;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /** The default constructor. */
    public
    ExceptionWrapper()
    {
        this(null, "");
    }

    /**
     * The constructor with the wrapped Java Exception object.
     *
     * @param exception The wrapped Java Exception object.
     */
    public
    ExceptionWrapper(Exception exception)
    {
        this(exception, "");
    }

    /**
     * The constructor with the wrapped Java Exception object
     * and an associated message.
     *
     * @param exception The wrapped Java Exception object.
     * @param message The message describing the exception.
     */
    public
    ExceptionWrapper(Exception exception,
                     String message)
    {
        // Calls the java.lang.Error constructor.
        super(message);

        // Inits internal state.
        exception_ = exception;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.util.api.ExceptionHolder.
    //
    // ==================================================================

    /**
     * Obtains the wrapped Java Exception object.
     *
     * @return The wrapped Java Exception object.
     */
    public Exception
    getException()
    {
        return exception_;
    }

    /**
     * Sets the wrapped Java Exception object.
     *
     * @param exception The wrapped Java Exception object.
     */
    public void
    setException(Exception exception)
    {
        exception_ = exception;
    }

    // ==================================================================
    //
    // Other public methods.
    //
    // ==================================================================
}
