/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.gui.common;

/** The concole's imports */
import org.objectweb.util.browser.naming.api.Entry;
import org.objectweb.util.browser.api.PropertyContainer;
import org.objectweb.util.browser.api.BrowserProperty;
import org.objectweb.util.browser.naming.wrappers.common.DefaultContextContainer;

/** The java AMI's imports */
import java.util.List;
import java.util.Iterator;
import java.util.Map;
import java.util.HashMap;

/**
 * Basic implementation of the Context interface.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * @version 0.1
 */

public abstract class DefaultPropertyContainer
    extends DefaultContextContainer
    implements PropertyContainer {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /**
     * The object to use to load new configuration.
     */
    protected BrowserProperty loader_;

    /**
     * This map stores the corresponding class.
     * Exemple : java.util.ArrayList => java.util.AbstractCollection
     *           Concequently, for java.util.ArrayList object, it directly 
     *           look for java.util.AbstractCollection element.
     */
    protected Map cache_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default contstructor
     * @param loader The object to use to load new configuration
     */
    public DefaultPropertyContainer(BrowserProperty loader) {
        super();
        loader_ = loader;
        cache_ = new HashMap();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Tries to load an element for the associated class name.
     * It calls the loader and adds the given entry into the context
     * @param className The name of the class 
     */
    protected Entry tryToLoad(String className) {
        Entry entry = getElement(className);
        if (entry != null)
            addEntry(entry.getOWName().getOWId(), entry.getOWValue());
        return entry;
    }

    /**
     * Tries to load an element for the associated class name.
     * @param className The name of the class 
     * @return The founded entry or null
     */
    protected abstract Entry getElement(String className);

    // ==================================================================
    //
    // Additional public methods for PropertyTools interface.
    //
    // ==================================================================

    /**
     * Finds the object associated value. 
     * If the key doesn't exist, it looks for in interfaces implemented 
     * by this class and in superclass of the entity
     * In order to have a string representation of the object, 
     * it takes his name (object.getClass().getName())
     * @param object The research key
     * @return The associated value - null is returned if no value exists
     */
    public Entry getRecursiveProperty(Object object) {
        Class c = object.getClass();
        // Looks for association into the cache
        if (cache_.containsKey(c.getName())) {
            return getOWLocalEntry((String) cache_.get(c.getName()));
        }
        ClassesInheritance ci = new ClassesInheritance(c);
        List list = ci.getInheritClasses();
        Iterator it = list.iterator();
        while (it.hasNext()) {
            Class class_ = (Class) it.next();
            Entry entry = getOWLocalEntry(class_.getName());
            if (entry == null) {
                entry = tryToLoad(class_.getName());
            }
            if (entry != null) {
                cache_.put(c.getName(), class_.getName());
                return entry;
            }
        }
        return null;
    }

}
