/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.gui.popup;

/** The browser's imports */
import org.objectweb.util.browser.api.ExtendedActionEvent;
import org.objectweb.util.browser.gui.common.TreeView;

/** The Java API's imports */
import java.awt.event.ActionEvent;

/**
 *
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class DefaultExtendedActionEvent implements ExtendedActionEvent {

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    protected ActionEvent actionEvent_;

    protected TreeView treeView_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    public DefaultExtendedActionEvent(ActionEvent e, TreeView treeView) {
        actionEvent_ = e;
        treeView_ = treeView;
    }

    // ==================================================================
    //
    // Public methods from ExtendedActionEvent interface.
    //
    // ==================================================================

    /** 
     * Returns the initial ActionEvent
     */
    public ActionEvent getActionEvent() {
        return actionEvent_;
    }

    /**
     * Returns a view on the tree
     * @return A view on the tree
     */
    public TreeView getTreeView() {
        return treeView_;
    }

    /**
     * Returns the wrapped object of value of the selected Entry.
     * Equivalent to <code>getTreeView().getValue()</code>
     */
    public Object getCurrentValue() {
        if (treeView_ != null) {
            return treeView_.getValue();
        }
        return null;
    }

    /**
     * Returns the wrapped object of value of the parent of the selected Entry.
     * Equivalent to <code>getTreeView().getParentValue()</code>
     */
    public Object getParentValue() {
        if (treeView_ != null) {
            return treeView_.getParentValue();
        }
        return null;
    }

}
