/*====================================================================

ObjectWeb Util CommandLine Package.
Copyright (C) 2003 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.cmdline.api;

// Package dependencies.
import org.objectweb.util.api.Identifiable;

/**
 * This interface represents an application with a command line.
 *
 * This provides the following properties:
 *
 * - MailingList: The associated mailing list of this development.
 *
 * - VersionInformation: The associated version information.
 *
 * This provides the following methods:
 *
 * - main and start: Starts the application.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public interface Application
         extends Identifiable,
                 CommandLineHolder,
                 ConsoleHolder
{
    /**
     * Obtains the mailing list associated to this development.
     *
     * @return The mailing list associated to this development.
     */
    public String
    getMailingList();

    /**
     * Obtains the associated version information.
     *
     * @return The associated version information.
     */
    public String[]
    getVersionInformation();

    /**
     * Reports an exception stack.
     *
     * @param exception The exception to report.
     */
    public void
    report_exception(Exception exception);

    /**
     * Executes the main function, i.e.
     * 1 - arguments = getCommandLine().parse(args);
     * 2 - status = starts(arguments);
     * 3 - System.exit(status);
     *
     * @param args The command line arguments.
     */
    public void
    runMain(String[] args);

    /**
     * Starts the main function.
     *
     * @param args The command line arguments.
     *
     * @return The status of the application.
     */
    public int
    start(String[] args);
}
