/*====================================================================

ObjectWeb Util Preprocessor Package.
Copyright (C) 2003 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.cpp.api;

// Package dependencies.
import java.util.Map;
import java.io.File;
import java.io.OutputStream;
import org.objectweb.util.cmdline.api.ConsoleHolder;

/**
 * This defines a simple interface to interact with preprocessors.
 *
 * This provides the following properties:
 *
 * - GenerateLineInformation: Indicates if #line information should be generated.
 *
 * - IncludeDirectory: The list of directories where included files
 *                     are searched.
 *
 * - Macro: The list of defined macros.
 *
 * This provides two preprocess operations.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public interface Preprocessor
         extends PreprocessorOperations,
                 org.objectweb.util.cmdline.api.ConsoleHolder
{
    /**
     * Obtains the GenerateLineInformation property.
     *
     * @return The GenerateLineInformation property.
     */
    public boolean
    getGenerateLineInformation();

    /**
     * Sets the GenerateLineInformation property.
     *
     * @param b The GenerateLineInformation property.
     */
    public void
    setGenerateLineInformation(boolean b);

    /**
     * Adds a directory to the list of include directories.
     *
     * @param directoru The directory to add.
     */
    public void
    addIncludeDirectory(String directory);

    /**
     * Obtains the list of include directories.
     *
     * @return The list of include directories.
     */
    public String[]
    getIncludeDirectory();

    /**
     * Sets the list of include directories.
     *
     * @param directories The list of include directories.
     */
    public void
    setIncludeDirectory(String[] directories);

    /**
     * Adds a macro (name - 1) to the list of declared macros.
     *
     * @param name The name of the macro to add.
     */
    public void
    addMacro(String name);

    /**
     * Adds a macro (name - value) to the list of declared macros.
     *
     * @param name The name of the macro to add.
     * @param value The value of the macro to add.
     */
    public void
    addMacro(String name,
             String value);

    /**
     * Removes a macro (name - value) from the list of declared macros.
     *
     * @param name The name of the macro to remove.
     */
    public void
    removeMacro(String name);

    /**
     * Obtains the list of declared macros.
     *
     * @return The list of declared macros.
     */
    public java.util.Map
    getMacro();

    /**
     * Sets the list of declared macros.
     *
     * @param macros The list of declared macros.
     */
    public void
    setMacro(java.util.Map macros);
}
